import { DocumentSnapshot } from "firebase-admin/firestore";
import { ModelConverter } from "jrx-ts";
export default abstract class FirestoreModelConverter<T extends Object> extends ModelConverter<T> {
    private isFunctionCompatible;
    /**
     * Converts the specified document snapshot into model T.
     * Returns undefined if the snapshot does not exist.
     */
    fromSnapshot(snapshot: DocumentSnapshot): T | undefined;
    /**
     * Converts the specified document snapshot into model T.
     * Returns null if the conversion fails.
     * Returns undefined if the snapshot does not exist.
     */
    fromSnapshotSafe(snapshot: DocumentSnapshot): T | null | undefined;
    /**
     * Converts the specified model into plain object compatible with Function response.
     */
    toPlainForFunction(model: T): any;
    /**
     * When sending the client response via Firebase Functions, certain values must be of supported types or it'll throw an error.
     * For example, Sending Timestamp via Function response will throw an error.
     * Setting this to true will encode the values to Function compatible types.
     */
    setFunctionCompatible(value: boolean): void;
    encodeDate(value: Date): any;
    decodeDate(value: any, defaultValue?: Date | undefined): Date;
    private encodeDateFirestore;
}
